# include <QtGui/QApplication>
# include <QtSvg/QSvgWidget>
# include <QtCore/QByteArray>

extern "C"
{
# include "mplib.h"
# include "mplibps.h"
# include "mplibsvg.h"
}

# include <cstdio>
# include <cstdlib>
# include <cstring>

# define MP_COMMAND(x) command = x ; mp_execute ( mp, command, strlen ( command ) )

int main ( int argc, char * argv [] )
{
	// initalizing mplib
	MP mp ;
	MP_options * opt = mp_options () ;
	opt -> command_line = argv [ 1 ] ;
	opt -> noninteractive = 1 ;
	mp = mp_initialize ( opt ) ;
	if ( ! mp ) exit ( EXIT_FAILURE ) ;

	// variable declarations
	const char * command ;
	mp_run_data * results ;
	mp_edge_object * curfig ;
	
	// commands to mplib
	MP_COMMAND ( "input plain ;" ) ;
	MP_COMMAND ( "beginfig ( 3 ) ;" ) ;
	MP_COMMAND ( "path p; p := dir ( -30 ) -- dir ( 90 ) -- dir ( 210 ) -- cycle ;" ) ;
	MP_COMMAND ( "draw ( p scaled 2cm ) withpen pencircle xscaled 8 yscaled 4 rotated 60 ;" ) ;
	MP_COMMAND ( "endfig ; end ;" ) ;

	// collecting svg output
	results = mp_rundata ( mp ) ;
	curfig = results -> edges ;
	mp_svg_ship_out ( curfig, 1 ) ;
	results = mp_rundata ( mp ) ;
	QByteArray svgcontents ( results -> ps_out . data ) ;
	
	// GUI initialization
	QApplication app ( argc, argv ) ;
	QSvgWidget svgwidget ;
	svgwidget . load ( svgcontents ) ;
	svgwidget . show () ;
	
	// closing up
	mp_finish ( mp ) ;
	return app . exec () ;
}
